globals [ energy x total-distance average-total-distance ]
turtles-own [ tenergy fddist]

to startup ;; When program first opened
  setup
end


to setup  ;; Called in startup and in setup button
  clear-all  ;; Clear the screen
  
  ;; Set up patches: make them white and draw the photobeam
  ask patches [
    set pcolor white
    if photo-beam? and pycor = 0 [ set pcolor red ]
  ]

  ;; Create and set up the turtles: make them fly shaped and with random position  
  create-turtles number-of-flies
  ask turtles [  
    set shape "fly"
    set size 20
    setxy (random-float 300) - 150 (random-float 300) - 150
  ]

  ;; Set the energy to match the study (Majercak et al., 1999)
  ;; A turtle's energy determines how much it moves on each tick
  

  if mutation = "perG" [
    if cycle = "Day four, 6:18" [     ;; 6:18, perG
      if hour < 3 [ set energy .6667 * hour + 3 ]
      if hour >= 3 and hour < 6 [ set energy -5.1637 * (hour ^ 2) + 45.807 * hour - 85.946 ]
      if hour >= 6 and hour < 11 [ set energy 3.4 * hour - 17.4 ]
      if hour >= 12.5 and hour < 12.5 [ set energy -12 * hour + 152 ]
      if hour >= 12.5 [ set energy .08696 * hour + .91304 ]
    ]
    if cycle = "Day five, D:D" [     ;; D:D, perG
      if hour < 11 [ set energy -0.0082 * (hour ^ 4) + 0.0934 * (hour ^ 3) - 0.2232 * (hour ^ 2) + 0.638 * hour + 16 ]
      if hour >= 11 and hour < 22 [ set energy -0.0009 * (hour ^ 5) + 0.0631 * (hour ^ 4) - 1.7341 * (hour ^ 3) + 23.294 * (hour ^ 2) - 152.71 * hour + 390.89 ]
      if hour >= 22 [ set energy -4 * (hour ^ 2) + 191.5 * hour - 2276 ]      
    ]   
  ] 
    
  if mutation = "perB'" [
    if cycle = "Day four, 6:18" [     ;; 6:18, perB
      if hour < 3.5 [ set energy 4 ]
      if hour >= 3.5 and hour < 6 [ set energy -8.8667 * (hour ^ 2) + 86.033 * hour - 188.5 ]
      if hour >= 6 and hour < 10 [ set energy 8.5 ]
      if hour >= 10 and hour < 12 [ set energy -7.5 * (hour ^ 3) + 235.25 * (hour ^ 2) - 2449.2 * hour + 8476 ]
      if hour >= 12 and hour < 20 [ set energy 1 ]
      if hour >= 20 [ set energy .75 * hour - 14 ]
    ]
    if cycle = "Day five, D:D" [     ;; D:D, perB
      if hour < 13 [ set energy 0.0004 * (hour ^ 6) - 0.0177 * (hour ^ 5) + 0.2786 * (hour ^ 4)- 1.9651 * (hour ^ 3) + 5.6117 * (hour ^ 2) - 1.008 * hour + 4 ]
      if hour >= 13 and hour < 22 [ set energy -0.0286 * (hour ^ 4) + 1.9286 * (hour ^ 3) - 48.029 * (hour ^ 2) + 522.07 * hour - 2081.1 ]
      if hour >= 22 [ set energy 1.5 * hour - 32 ]
    ]    
  ]
  
  if mutation = "perA" [
    if cycle = "Day four, 6:18" [     ;; 6:18, perA
      if hour < 4 [ set energy 5 ]
      if hour >= 4 and hour < 6.5 [ set energy 0.6667 * (hour ^ 4) - 11.185 * (hour ^ 3) + 56.5 * (hour ^ 2) - 57.632 * hour - 123.56 ]
      if hour >= 6.5 and hour < 9.5 [ set energy 7 ]
      if hour >= 9.5 and hour < 12 [ set energy -2.9667 * (hour ^ 3) + 87.15 * (hour ^ 2) - 843.18 * hour + 2695.5 ]
      if hour >= 12 [ set energy 0.375 * hour - 4 ]
    ]
    if cycle = "Day five, D:D" [     ;; D:D, perA
      if hour < 22 [ set energy -3E-05 * (hour ^ 6) + 0.0016 * (hour ^ 5) - 0.0382 * (hour ^ 4) + 0.3857 * (hour ^ 3) - 1.5588 * (hour ^ 2) + 2.0887 * hour + 6.123 ]
      if hour >= 22 [ set energy 2.5 * hour - 54 ]
    ]   
  ]
  
  if mutation = "per01" [
    if cycle = "Day four, 6:18" [     ;; 6:18, per01
      if hour < 4 [ set energy 0.625 * hour + 2.5 ]
      if hour >= 4 and hour < 6 [ set energy -11 * (hour ^ 2) + 113 * hour - 271 ]
      if hour >= 6 and hour < 10 [ set energy 11 ]
      if hour >= 10 and hour < 12 [ set energy -11.25 * (hour ^ 2) + 242.25 * hour - 1286.5 ]
      if hour >= 12 [ set energy 0.16667 * hour - 1.5 ]
    ]
    if cycle = "Day five, D:D" [     ;; D:D, per01
      user-message "invalid options"
      set cycle "Day four, 6:18"
    ]   
  ]

  
  
  ask turtles [ set tenergy 1.75 * energy - .2 + random-float .4 ]
  ask turtles [ if tenergy < 0 [set tenergy random-float .2 ] ]   ;; can't have a negative energy      

  reset-ticks
end


to go ;; Run when "go" button pressed
  set average-total-distance (total-distance / number-of-flies)  ;; For the monitor
  if ticks >= 1000 [ stop ]     ;; Only run for 1000 ticks
  
  ask turtles [     ;; Make the turtles move
    ifelse trails-on? [pd] [pu]
    rt ((random-float 30 ) - 15) * tenergy ^ .4 / 3
    set fddist random-float tenergy / 10
    fd fddist
    set total-distance total-distance + fddist
    if ycor >= max-pycor or ycor <= (- max-pycor) [     ;; Make the turtles bounce off the walls
      facexy xcor 0
    ]
    if xcor >= max-pxcor or xcor <= (- max-pxcor) [
      facexy 0 ycor
    ]
  ]
  tick
end


to clear-flies     ;; Make turtles invisible
  ask turtles [
    set size 0
  ]
end

to see-flies     ;; Make the turtles visible
  ask turtles [
    set size 20
  ]
end
@#$#@#$#@
GRAPHICS-WINDOW
140
10
631
522
150
150
1.6
1
10
1
1
1
0
0
0
1
-150
150
-150
150
0
0
1
ticks
3000.0

BUTTON
5
10
70
43
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
5
45
135
78
number-of-flies
number-of-flies
1
10
5
1
1
NIL
HORIZONTAL

BUTTON
70
10
135
43
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SWITCH
5
153
135
186
trails-on?
trails-on?
0
1
-1000

SWITCH
5
117
135
150
photo-beam?
photo-beam?
1
1
-1000

BUTTON
4
188
69
221
clear flies
clear-flies
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
69
188
135
221
view flies
see-flies
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
4
224
135
269
NIL
average-total-distance
2
1
11

SLIDER
5
81
135
114
hour
hour
0
23.99
0
.01
1
NIL
HORIZONTAL

CHOOSER
4
272
135
317
mutation
mutation
"perG" "perB'" "perA"
0

CHOOSER
4
320
142
365
cycle
cycle
"Day four, 6:18" "Day five, D:D"
0

@#$#@#$#@
## WHAT IS IT?

This section could give a general understanding of what the model is trying to show or explain.

## HOW IT WORKS

This section could explain what rules the agents use to create the overall behavior of the model.

## HOW TO USE IT

This section could explain how to use the model, including a description of each of the items in the interface tab.

## THINGS TO NOTICE

This section could give some ideas of things for the user to notice while running the model.

## THINGS TO TRY

This section could give some ideas of things for the user to try to do (move sliders, switches, etc.) with the model.

## EXTENDING THE MODEL

This section could give some ideas of things to add or change in the procedures tab to make the model more complicated, detailed, accurate, etc.

## NETLOGO FEATURES

This section could point out any especially interesting or unusual features of NetLogo that the model makes use of, particularly in the Procedures tab.  It might also point out places where workarounds were needed because of missing features.

## RELATED MODELS

This section could give the names of models in the NetLogo Models Library or elsewhere which are of related interest.

## CREDITS AND REFERENCES

This section could contain a reference to the model's URL on the web if it has one, as well as any other necessary credits or references.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

fly
true
0
Polygon -11221820 true false 127 198 186 97 215 179 222 221 213 266 200 274 189 277 164 259 133 226
Polygon -11221820 true false 174 198 115 97 86 179 79 221 88 266 101 274 112 277 137 259 168 226
Polygon -7500403 true true 150 30 130 34 119 41 107 53 104 65 105 78 116 83 131 80 150 75 150 60 150 30
Line -7500403 true 139 36 116 6
Polygon -7500403 true true 150 30 170 34 181 41 193 53 196 65 195 78 184 83 169 80 150 75 150 60 150 30
Polygon -7500403 true true 180 165 165 135
Line -7500403 true 161 36 184 6
Polygon -14835848 true false 150 150 135 150 122 156 112 162 108 169 110 179 131 220 142 230 155 232
Polygon -14835848 true false 150 150 165 150 178 156 188 162 192 169 190 179 169 220 158 230 145 232
Circle -16777216 true false 99 40 40
Circle -16777216 true false 161 40 40
Polygon -14835848 true false 126 195 109 207 118 248 99 270 98 268 114 249 104 205 121 185
Polygon -14835848 true false 174 195 191 207 182 248 201 270 202 268 186 249 196 205 179 185
Polygon -14835848 true false 122 130 114 151 102 134 100 138 115 157 127 136
Polygon -14835848 true false 178 130 186 151 198 134 200 138 185 157 173 136
Polygon -7500403 true true 150 75 165 75 187 92 193 101 192 110 178 152 171 165 157 171 148 171
Polygon -7500403 true true 150 75 135 75 113 92 107 101 108 110 122 152 129 165 143 171 152 171
Polygon -7500403 true true 102 136 90 126 62 153 62 157 57 149 61 151 90 123 101 132
Polygon -7500403 true true 198 136 210 126 238 153 238 157 243 149 239 151 210 123 199 132
Polygon -7500403 true true 116 93 103 83 77 64 47 70 47 72 77 67 103 89 113 103 115 101
Polygon -7500403 true true 184 93 197 83 223 64 253 70 253 72 223 67 197 89 187 103 185 101

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
